@@ -13,7 +13,7 @@ wrapper: Py3cwClosure = None
 ''' This endpoint was not present in the py3cw module
 @logged
 @with_py3cw
-def get():
+def get(payload: dict = None):
     """
     GET /ver1/time
     Test connectivity to the Rest API and get the current server time (Permission: NONE, Security: NONE)
@@ -22,6 +22,7 @@ def get():
     error, data = wrapper.request(
         entity='<py3cw_entity>',
         action='<py3cw_action>',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 '''
